@@ -6,8 +6,8 @@
 ****************************************************************************/
 
 
-#ifndef _THREAD_H
-#define _THREAD_H   
+#ifndef CUBE_THREAD_H
+#define CUBE_THREAD_H   
 
 /*
  *----------------------------------------------------------------------------
